==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/live/v20180801/models/DeleteRecordTaskRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteRecordTaskRequest extends AbstractModel{

    /**
    * 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
    */
    @SerializedName("TaskId")
    @Expose
    private String TaskId;

    /**
     * Get 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。 
     * @return TaskId 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     */
    public String getTaskId() {
        return this.TaskId;
    }

    /**
     * Set 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     * @param TaskId 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     */
    public void setTaskId(String TaskId) {
        this.TaskId = TaskId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TaskId", this.TaskId);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/live/v20180801/models/DeleteRecordTaskRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DeleteRecordTaskRequest extends AbstractModel{

    /**
    * 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
    */
    @SerializedName("TaskId")
    @Expose
    private String TaskId;

    /**
     * Get 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。 
     * @return TaskId 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     */
    public String getTaskId() {
        return this.TaskId;
    }

    /**
     * Set 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     * @param TaskId 任务ID，CreateRecordTask返回。删除TaskId指定的录制任务。
     */
    public void setTaskId(String TaskId) {
        this.TaskId = TaskId;
    }

    public DeleteRecordTaskRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DeleteRecordTaskRequest(DeleteRecordTaskRequest source) {
        if (source.TaskId != null) {
            this.TaskId = new String(source.TaskId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "TaskId", this.TaskId);

    }
}
